# Linux desktop multimedia integration with Home Assistant

This package contains the core protocol and functionality that various parts
of the Home Assistant integration with MPRIS need.

To get the rest of the components, check out
[the agent itself](https://github.com/Rudd-O/hassmpris_agent) as well as the
[command-line client](https://github.com/Rudd-O/hassmpris_client).
